/**
 * General texts functions
 */
'use strict';

/**
 * Creates a general text element.
 */
function createGeneralTextElement(textId, swedish, english, danish, german) {
    var html =
        '<div class="general-text-' + textId + ' mdl-shadow--2dp mdl-cell mdl-cell--12-col mdl-grid" style="background-color: white;">' +
        '  <form class="general-form mdl-cell mdl-cell--12-col mdl-grid" id="general-form-' + textId + '" action="#">' +
        '    <div class="mdl-cell mdl-cell--2-col mdl-cell--8-col-tablet mdl-cell--4-col-phone">' +
        '      <h6>' + textId + ': </h6>' +
        '    </div>' +
        '    <div class="mdl-cell mdl-cell--2-col mdl-cell--4-col-tablet mdl-cell--4-col-phone">' +
        '      <div class="mdl-textfield mdl-js-textfield mdl-textfield--floating-label">' +
        '        <textarea class="swedish-generalText mdl-textfield__input" rows="2" id="swedish-generalText-' + textId + '"></textarea>' +
        '        <label class="mdl-textfield__label" for="swedish-generalText-' + textId + '">Swedish</label>' +
        '      </div>' +
        '    </div>' +
        '    <div class="mdl-cell mdl-cell--2-col mdl-cell--4-col-tablet mdl-cell--4-col-phone">' +
        '      <div class="mdl-textfield mdl-js-textfield mdl-textfield--floating-label">' +
        '        <textarea class="enlish-generalText mdl-textfield__input" rows="2" id="enlish-generalText-' + textId + '"></textarea>' +
        '        <label class="mdl-textfield__label" for="enlish-generalText-' + textId + '">English</label>' +
        '      </div>' +
        '    </div>' +
        '    <div class="mdl-cell mdl-cell--2-col mdl-cell--4-col-tablet mdl-cell--4-col-phone">' +
        '      <div class="mdl-textfield mdl-js-textfield mdl-textfield--floating-label">' +
        '        <textarea class="danish-generalText mdl-textfield__input" rows="2" id="danish-generalText-' + textId + '"></textarea>' +
        '        <label class="mdl-textfield__label" for="danish-generalText-' + textId + '">Danish</label>' +
        '      </div>' +
        '    </div>' +
        '    <div class="mdl-cell mdl-cell--2-col mdl-cell--4-col-tablet mdl-cell--4-col-phone">' +
        '      <div class="mdl-textfield mdl-js-textfield mdl-textfield--floating-label">' +
        '        <textarea class="german-generalText mdl-textfield__input" rows="2" id="german-generalText-' + textId + '"></textarea>' +
        '        <label class="mdl-textfield__label" for="german-generalText-' + textId + '">German</label>' +
        '      </div>' +
        '    </div>' +
        '    <div class="mdl-cell mdl-cell--2-col mdl-cell--8-col-tablet mdl-cell--4-col-phone" style="padding: 10px 0 0 50px;">' +
        '      <button type="submit" class="mdl-button mdl-js-button mdl-button--raised mdl-js-ripple-effect">Update</button>' +
        '    </div>' +
        '  </form>' +
        '</div>';

    // Create the DOM element from the HTML.
    var div = document.createElement('div');
    div.innerHTML = html;
    var generalTextElement = div.firstChild;

    var generalTextForm = generalTextElement.getElementsByClassName('general-form')[0];
    var swedishInput = generalTextElement.getElementsByClassName('swedish-generalText')[0];
    var englishInput = generalTextElement.getElementsByClassName('enlish-generalText')[0];
    var danishInput = generalTextElement.getElementsByClassName('danish-generalText')[0];
    var germanInput = generalTextElement.getElementsByClassName('german-generalText')[0];

    // Set values.   
    generalTextElement.getElementsByClassName('swedish-generalText')[0].value = swedish;
    generalTextElement.getElementsByClassName('enlish-generalText')[0].value = english;
    generalTextElement.getElementsByClassName('danish-generalText')[0].value = danish;
    generalTextElement.getElementsByClassName('german-generalText')[0].value = german;

    if (componentHandler) {
        componentHandler.upgradeElements(generalTextElement.getElementsByClassName('mdl-textfield'));
    }

    // Update General Text data
    generalTextForm.onsubmit = function (e) {
        e.preventDefault();
        updateGeneralTextData(textId, swedishInput.value, englishInput.value, danishInput.value, germanInput.value);
    };

    return generalTextElement;
}

/**
 * Updates general text data on the Firebase DB.
 */
function updateGeneralTextData(textId, swedish, english, danish, german) {

    var generalTextData = {
        swedish: swedish,
        english: english,
        danish: danish,
        german: german
    };
    var updates = {};
    updates['/General-Texts/' + textId] = generalTextData;

    return firebase.database().ref().update(updates);
}


/**
 * Creates a general text Edit element.
 */
function createGeneralTextEditElement() {
    var html =
        '<div class="general-textedit mdl-shadow--2dp mdl-cell mdl-cell--12-col mdl-grid" style="background-color: white;">' +
        '  <div class="mdl-cell mdl-cell--12-col mdl-cell--8-col-tablet mdl-cell--4-col-phone">' +
        '    <h4>Add New GeneralText</h4>' +
        '  </div>' +
        '  <form class="generaledit-form mdl-cell mdl-cell--12-col mdl-grid" id="generaledit-form" action="#">' +
        '    <div class="mdl-cell mdl-cell--2-col mdl-cell--8-col-tablet mdl-cell--4-col-phone">' +
        '      <div class="mdl-textfield mdl-js-textfield mdl-textfield--floating-label">' +
        '        <textarea class="generalTextId mdl-textfield__input" rows="2" id="generalTextId"></textarea>' +
        '        <label class="mdl-textfield__label" for="generalTextId">GeneralTextId</label>' +
        '      </div>' +
        '    </div>' +
        '    <div class="mdl-cell mdl-cell--2-col mdl-cell--4-col-tablet mdl-cell--4-col-phone">' +
        '      <div class="mdl-textfield mdl-js-textfield mdl-textfield--floating-label">' +
        '        <textarea class="swedish-generalTextEdit mdl-textfield__input" rows="2" id="swedish-generalTextEdit"></textarea>' +
        '        <label class="mdl-textfield__label" for="swedish-generalTextEdit">Swedish</label>' +
        '      </div>' +
        '    </div>' +
        '    <div class="mdl-cell mdl-cell--2-col mdl-cell--4-col-tablet mdl-cell--4-col-phone">' +
        '      <div class="mdl-textfield mdl-js-textfield mdl-textfield--floating-label">' +
        '        <textarea class="enlish-generalTextEdit mdl-textfield__input" rows="2" id="enlish-generalTextEdit"></textarea>' +
        '        <label class="mdl-textfield__label" for="enlish-generalTextEdit">English</label>' +
        '      </div>' +
        '    </div>' +
        '    <div class="mdl-cell mdl-cell--2-col mdl-cell--4-col-tablet mdl-cell--4-col-phone">' +
        '      <div class="mdl-textfield mdl-js-textfield mdl-textfield--floating-label">' +
        '        <textarea class="danish-generalTextEdit mdl-textfield__input" rows="2" id="danish-generalTextEdit"></textarea>' +
        '        <label class="mdl-textfield__label" for="danish-generalTextEdit">Danish</label>' +
        '      </div>' +
        '    </div>' +
        '    <div class="mdl-cell mdl-cell--2-col mdl-cell--4-col-tablet mdl-cell--4-col-phone">' +
        '      <div class="mdl-textfield mdl-js-textfield mdl-textfield--floating-label">' +
        '        <textarea class="german-generalTextEdit mdl-textfield__input" rows="2" id="german-generalTextEdit"></textarea>' +
        '        <label class="mdl-textfield__label" for="german-generalTextEdit">German</label>' +
        '      </div>' +
        '    </div>' +
        '    <div class="mdl-cell mdl-cell--2-col mdl-cell--8-col-tablet mdl-cell--4-col-phone" style="padding: 10px 0 0 50px;">' +
        '      <button type="submit" class="mdl-button mdl-js-button mdl-button--raised mdl-js-ripple-effect">Add</button>' +
        '    </div>' +
        '  </form>' +
        '</div>';

    // Create the DOM element from the HTML.
    var div = document.createElement('div');
    div.innerHTML = html;
    var generalTextElement = div.firstChild;

    var generalTextForm = generalTextElement.getElementsByClassName('generaledit-form')[0];
    var textIdInput = generalTextElement.getElementsByClassName('generalTextId')[0];
    var swedishInput = generalTextElement.getElementsByClassName('swedish-generalTextEdit')[0];
    var englishInput = generalTextElement.getElementsByClassName('enlish-generalTextEdit')[0];
    var danishInput = generalTextElement.getElementsByClassName('danish-generalTextEdit')[0];
    var germanInput = generalTextElement.getElementsByClassName('german-generalTextEdit')[0];

    // Set values.
    generalTextElement.getElementsByClassName('generalTextId')[0].value = "";
    generalTextElement.getElementsByClassName('swedish-generalTextEdit')[0].value = "";
    generalTextElement.getElementsByClassName('enlish-generalTextEdit')[0].value = "";
    generalTextElement.getElementsByClassName('danish-generalTextEdit')[0].value = "";
    generalTextElement.getElementsByClassName('german-generalTextEdit')[0].value = "";

    if (componentHandler) {
        componentHandler.upgradeElements(generalTextElement.getElementsByClassName('mdl-textfield'));
    }

    // Update General Text data
    generalTextForm.onsubmit = function (e) {
        e.preventDefault();
        addGeneralTextData(textIdInput.value, swedishInput.value, englishInput.value, danishInput.value, germanInput.value);
        generalTextElement.getElementsByClassName('generalTextId')[0].value = "";
        generalTextElement.getElementsByClassName('swedish-generalTextEdit')[0].value = "";
        generalTextElement.getElementsByClassName('enlish-generalTextEdit')[0].value = "";
        generalTextElement.getElementsByClassName('danish-generalTextEdit')[0].value = "";
        generalTextElement.getElementsByClassName('german-generalTextEdit')[0].value = "";
    };

    const DURef = firebase.database().ref('devusers');
    DURef.child(currentUID).get().then((snapshot) => {
        if (snapshot.exists()) {
            //console.log(snapshot.val());
            generalTextElement.style.display = 'block';
            isDev = true;
        } else {
            //console.log("No data available");
            generalTextElement.style.display = 'none';
            isDev = false;
        }
    }).catch((error) => {
        console.error(error);
    });

    return generalTextElement;
}

/**
 * Updates general text data on the Firebase DB.
 */
function addGeneralTextData(textId, swedish, english, danish, german) {

    var generalTextData = {
        swedish: swedish,
        english: english,
        danish: danish,
        german: german
    };
    var updates = {};
    updates['/General-Texts/' + textId] = generalTextData;

    return firebase.database().ref().update(updates);
}